==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/field_types/TextField.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/fragment_configuration/field_types/TextField.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './TextFieldDelegateTemplate.soy', './TextField.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.TextField = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./TextFieldDelegateTemplate.soy");

  var _TextField = _interopRequireDefault(require("./TextField.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * TextField
   */
  var TextField =
  /*#__PURE__*/
  function (_Component) {
    _inherits(TextField, _Component);

    function TextField() {
      _classCallCheck(this, TextField);

      return _possibleConstructorReturn(this, _getPrototypeOf(TextField).apply(this, arguments));
    }

    _createClass(TextField, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;
        var value = state.configurationValues[this.field.name];

        if (value) {
          nextState = _objectSpread({}, state, {
            configurationValues: _objectSpread({}, state.configurationValues, _defineProperty({}, this.field.name, value))
          });
        }

        return nextState;
      }
      /**
       * Handle Text Value Change
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleTextValueChanged",
      value: function _handleTextValueChanged(event) {
        var targetElement = event.delegateTarget;
        this.emit('fieldValueChanged', {
          name: this.field.name,
          value: "".concat(targetElement.value)
        });
      }
    }]);

    return TextField;
  }(_metalComponent["default"]);

  exports.TextField = TextField;
  TextField.STATE = {
    /**
     * The configuration field
     * @review
     * @type {object}
     */
    field: _metalState.Config.shapeOf({
      dataType: _metalState.Config.string(),
      defaultValue: _metalState.Config.string(),
      description: _metalState.Config.string(),
      label: _metalState.Config.string(),
      name: _metalState.Config.string(),
      type: _metalState.Config.string(),
      typeOptions: _metalState.Config.object()
    })
  };

  _metalSoy["default"].register(TextField, _TextField["default"]);

  var _default = TextField;
  exports["default"] = _default;
  //# sourceMappingURL=TextField.es.js.map
});
//# sourceMappingURL=TextField.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/field_types/TextField.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/floating_toolbar/fragment_configuration/field_types/TextField.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './TextFieldDelegateTemplate.soy', './TextField.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.TextField = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./TextFieldDelegateTemplate.soy");

  var _TextField = _interopRequireDefault(require("./TextField.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * TextField
   */
  var TextField = /*#__PURE__*/function (_Component) {
    _inherits(TextField, _Component);

    function TextField() {
      _classCallCheck(this, TextField);

      return _possibleConstructorReturn(this, _getPrototypeOf(TextField).apply(this, arguments));
    }

    _createClass(TextField, [{
      key: "prepareStateForRender",

      /**
       * @inheritdoc
       * @review
       */
      value: function prepareStateForRender(state) {
        var nextState = state;
        var value = state.configurationValues[this.field.name];

        if (value) {
          nextState = _objectSpread({}, state, {
            configurationValues: _objectSpread({}, state.configurationValues, _defineProperty({}, this.field.name, value))
          });
        }

        return nextState;
      }
      /**
       * Handle Text Value Change
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleTextValueChanged",
      value: function _handleTextValueChanged(event) {
        var targetElement = event.delegateTarget;
        this.emit('fieldValueChanged', {
          name: this.field.name,
          value: "".concat(targetElement.value)
        });
      }
    }]);

    return TextField;
  }(_metalComponent["default"]);

  exports.TextField = TextField;
  TextField.STATE = {
    /**
     * The configuration field
     * @review
     * @type {object}
     */
    field: _metalState.Config.shapeOf({
      dataType: _metalState.Config.string(),
      defaultValue: _metalState.Config.string(),
      description: _metalState.Config.string(),
      label: _metalState.Config.string(),
      name: _metalState.Config.string(),
      type: _metalState.Config.string(),
      typeOptions: _metalState.Config.object()
    })
  };

  _metalSoy["default"].register(TextField, _TextField["default"]);

  var _default = TextField;
  exports["default"] = _default;
  //# sourceMappingURL=TextField.es.js.map
});
//# sourceMappingURL=TextField.es.js.map
